@@ -7,7 +7,7 @@ import gzip
 import requests # type: ignore
 import ijson # type: ignore
 from dwh_oppfolging.transforms.functions import dict_to_string, string_to_sha256_hash, string_to_naive_norwegian_datetime
-from dwh_oppfolging.apis.brreg_api_v1_types import PagedRequestForEmbeddedList, Update
+from dwh_oppfolging.apis.brreg_api_v1_types import PagedRequestForEmbeddedList, Update, PagedRequestError, UnpagedRequestForEmbeddedList
 
 
 API_VERSION = 1
@@ -103,7 +103,14 @@ def get_latest_records_for_unit(download_date: datetime, last_modified_date: dat
     list_key = "oppdaterte" + unit_name.capitalize()
     params = {"dato": last_modified_date.isoformat(timespec="milliseconds") + "Z"}
     orgnr_record_lkp: dict = {} # {orgnr from latest update for that orgnr: latest fact for that orgnr}
-    for updates in PagedRequestForEmbeddedList(url, params, headers, {}, page_size, list_key, timeout=100):
+
+    try:
+        iter_obj = PagedRequestForEmbeddedList(url, params, headers, {}, page_size, list_key, timeout=100)
+    except PagedRequestError:
+        logging.info("Using unpaged request, as paged request will fail due to API Limitations")
+        iter_obj = UnpagedRequestForEmbeddedList(url, params, headers, {}, size=page_size, list_key=list_key, timeout=100) # type: ignore
+    
+    for updates in iter_obj:
         # only keep the latest updates for each orgnr
         # since updates is already sorted with ascending update id, we can just overwrite
         orgnr_update_lkp = {update.orgnr: update for update in map(_build_update_struct, updates)}
