@@ -1,7 +1,7 @@
 "Sub-module for data types"
 
 from dataclasses import dataclass
-from typing import Callable, Any, Type, ClassVar
+from typing import Callable, Any, Type
 
 
 @dataclass
